==> igniteui-webcomponents-layouts-4.3.2.tgz: package/esm5/lib/igc-list-panel-item-model.js <==
import { ListPanelItemModel as ListPanelItemModel_internal } from "./ListPanelItemModel";
import { ensureBool } from "igniteui-webcomponents-core";
var IgcListPanelItemModel = /** @class */ /*@__PURE__*/ (function () {
    function IgcListPanelItemModel() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgcListPanelItemModel.prototype.createImplementation = function () {
        return new ListPanelItemModel_internal();
    };
    Object.defineProperty(IgcListPanelItemModel.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcListPanelItemModel.prototype.onImplementationCreated = function () {
    };
    IgcListPanelItemModel.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgcListPanelItemModel.prototype, "dataRow", {
        get: function () {
            return this.i.m;
        },
        set: function (v) {
            this.i.m = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcListPanelItemModel.prototype, "rowHeight", {
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcListPanelItemModel.prototype, "rowObject", {
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            this.i.o = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcListPanelItemModel.prototype, "isModelDirty", {
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgcListPanelItemModel.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    return IgcListPanelItemModel;
}());
export { IgcListPanelItemModel };

==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm5/lib/igc-list-panel-item-model.js <==
import { ListPanelItemModel as ListPanelItemModel_internal } from "./ListPanelItemModel";
import { ensureBool } from "igniteui-webcomponents-core";
var IgcListPanelItemModel = /** @class */ /*@__PURE__*/ (function () {
    function IgcListPanelItemModel() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgcListPanelItemModel.prototype.createImplementation = function () {
        return new ListPanelItemModel_internal();
    };
    Object.defineProperty(IgcListPanelItemModel.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcListPanelItemModel.prototype.onImplementationCreated = function () {
    };
    IgcListPanelItemModel.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgcListPanelItemModel.prototype, "dataRow", {
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcListPanelItemModel.prototype, "rowHeight", {
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcListPanelItemModel.prototype, "rowObject", {
        get: function () {
            return this.i.p;
        },
        set: function (v) {
            this.i.p = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcListPanelItemModel.prototype, "isModelDirty", {
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgcListPanelItemModel.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    return IgcListPanelItemModel;
}());
export { IgcListPanelItemModel };
